@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -22,7 +24,7 @@ class CreateFlowServiceRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Definition: 定义文本（JSON格式）
         :type Definition: str
         :param FlowServiceName: 状态机所属服务名
@@ -37,6 +39,10 @@ class CreateFlowServiceRequest(AbstractModel):
         :type RoleResource: str
         :param Description: 备注
         :type Description: str
+        :param EnableCLS: 是否开启CLS日志投递功能
+        :type EnableCLS: bool
+        :param Input: 该状态机的默认输入
+        :type Input: str
         """
         self.Definition = None
         self.FlowServiceName = None
@@ -45,6 +51,8 @@ class CreateFlowServiceRequest(AbstractModel):
         self.FlowServiceChineseName = None
         self.RoleResource = None
         self.Description = None
+        self.EnableCLS = None
+        self.Input = None
 
 
     def _deserialize(self, params):
@@ -55,6 +63,15 @@ class CreateFlowServiceRequest(AbstractModel):
         self.FlowServiceChineseName = params.get("FlowServiceChineseName")
         self.RoleResource = params.get("RoleResource")
         self.Description = params.get("Description")
+        self.EnableCLS = params.get("EnableCLS")
+        self.Input = params.get("Input")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class CreateFlowServiceResponse(AbstractModel):
@@ -63,7 +80,7 @@ class CreateFlowServiceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FlowServiceResource: 状态机所属服务资源
         :type FlowServiceResource: str
         :param CreateDate: 生成日期
@@ -88,7 +105,7 @@ class DescribeExecutionHistoryRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExecutionResourceName: 执行资源名
         :type ExecutionResourceName: str
         """
@@ -97,6 +114,13 @@ class DescribeExecutionHistoryRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ExecutionResourceName = params.get("ExecutionResourceName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeExecutionHistoryResponse(AbstractModel):
@@ -105,7 +129,7 @@ class DescribeExecutionHistoryResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Events: 执行的事件列表
         :type Events: list of ExecutionEvent
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
@@ -131,7 +155,7 @@ class DescribeExecutionRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExecutionResourceName: 执行资源名
         :type ExecutionResourceName: str
         """
@@ -140,6 +164,13 @@ class DescribeExecutionRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.ExecutionResourceName = params.get("ExecutionResourceName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeExecutionResponse(AbstractModel):
@@ -148,7 +179,7 @@ class DescribeExecutionResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExecutionResourceName: 执行资源名
         :type ExecutionResourceName: str
         :param Name: 资源名称
@@ -203,7 +234,7 @@ class DescribeExecutionsRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param StateMachineResourceName: 状态机资源名
         :type StateMachineResourceName: str
         :param PageSize: 页大小，最大100
@@ -228,6 +259,13 @@ class DescribeExecutionsRequest(AbstractModel):
         self.PageIndex = params.get("PageIndex")
         self.FilterExecutionStatus = params.get("FilterExecutionStatus")
         self.FilterExecutionResourceName = params.get("FilterExecutionResourceName")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeExecutionsResponse(AbstractModel):
@@ -236,7 +274,7 @@ class DescribeExecutionsResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -253,7 +291,7 @@ class DescribeFlowServiceDetailRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FlowServiceResource: 状态机所属服务资源名
         :type FlowServiceResource: str
         """
@@ -262,6 +300,13 @@ class DescribeFlowServiceDetailRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.FlowServiceResource = params.get("FlowServiceResource")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeFlowServiceDetailResponse(AbstractModel):
@@ -270,7 +315,7 @@ class DescribeFlowServiceDetailResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FlowServiceName: 状态机所属服务名
         :type FlowServiceName: str
         :param Status: 状态机状态
@@ -291,6 +336,15 @@ class DescribeFlowServiceDetailResponse(AbstractModel):
         :param FlowServiceChineseName: 状态机所属服务中文名
 注意：此字段可能返回 null，表示取不到有效值。
         :type FlowServiceChineseName: str
+        :param EnableCLS: 是否开启日志CLS服务
+注意：此字段可能返回 null，表示取不到有效值。
+        :type EnableCLS: bool
+        :param CLSUrl: CLS日志查看地址
+注意：此字段可能返回 null，表示取不到有效值。
+        :type CLSUrl: str
+        :param FlowInput: 工作流提示输入
+注意：此字段可能返回 null，表示取不到有效值。
+        :type FlowInput: str
         :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
         :type RequestId: str
         """
@@ -302,6 +356,9 @@ class DescribeFlowServiceDetailResponse(AbstractModel):
         self.CreateDate = None
         self.Description = None
         self.FlowServiceChineseName = None
+        self.EnableCLS = None
+        self.CLSUrl = None
+        self.FlowInput = None
         self.RequestId = None
 
 
@@ -314,6 +371,9 @@ class DescribeFlowServiceDetailResponse(AbstractModel):
         self.CreateDate = params.get("CreateDate")
         self.Description = params.get("Description")
         self.FlowServiceChineseName = params.get("FlowServiceChineseName")
+        self.EnableCLS = params.get("EnableCLS")
+        self.CLSUrl = params.get("CLSUrl")
+        self.FlowInput = params.get("FlowInput")
         self.RequestId = params.get("RequestId")
 
 
@@ -323,7 +383,7 @@ class DescribeFlowServicesRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Offset: 偏移量，默认为0。
         :type Offset: int
         :param Limit: 返回数量，默认为20，最大值为100。
@@ -345,6 +405,13 @@ class DescribeFlowServicesRequest(AbstractModel):
                 obj = Filter()
                 obj._deserialize(item)
                 self.Filters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class DescribeFlowServicesResponse(AbstractModel):
@@ -353,7 +420,7 @@ class DescribeFlowServicesResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FlowServiceSet: 用户的状态机列表
         :type FlowServiceSet: list of StateMachine
         :param TotalCount: 用户的状态机总数
@@ -383,7 +450,7 @@ class ExecutionEvent(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExecutionResourceName: 执行资源名
         :type ExecutionResourceName: str
         :param EventId: 自增序号
@@ -421,6 +488,13 @@ class ExecutionEvent(AbstractModel):
         self.Timestamp = params.get("Timestamp")
         self.Content = params.get("Content")
         self.Exception = params.get("Exception")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class Filter(AbstractModel):
@@ -429,7 +503,7 @@ class Filter(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Name: 过滤器名字
         :type Name: str
         :param Values: 过滤器值的数组
@@ -442,6 +516,13 @@ class Filter(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Values = params.get("Values")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyFlowServiceRequest(AbstractModel):
@@ -450,7 +531,7 @@ class ModifyFlowServiceRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FlowServiceResource: 状态机资源名
         :type FlowServiceResource: str
         :param Definition: 定义JSON
@@ -467,6 +548,8 @@ class ModifyFlowServiceRequest(AbstractModel):
         :type RoleResource: str
         :param Description: 状态机备注
         :type Description: str
+        :param EnableCLS: 是否允许日志投递
+        :type EnableCLS: bool
         """
         self.FlowServiceResource = None
         self.Definition = None
@@ -476,6 +559,7 @@ class ModifyFlowServiceRequest(AbstractModel):
         self.Type = None
         self.RoleResource = None
         self.Description = None
+        self.EnableCLS = None
 
 
     def _deserialize(self, params):
@@ -487,6 +571,14 @@ class ModifyFlowServiceRequest(AbstractModel):
         self.Type = params.get("Type")
         self.RoleResource = params.get("RoleResource")
         self.Description = params.get("Description")
+        self.EnableCLS = params.get("EnableCLS")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ModifyFlowServiceResponse(AbstractModel):
@@ -495,7 +587,7 @@ class ModifyFlowServiceResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FlowServiceResource: 状态机资源名
         :type FlowServiceResource: str
         :param UpdateDate: 更新时间
@@ -520,7 +612,7 @@ class StartExecutionRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param StateMachineResourceName: 状态机资源名
         :type StateMachineResourceName: str
         :param Input: 输入参数
@@ -537,6 +629,13 @@ class StartExecutionRequest(AbstractModel):
         self.StateMachineResourceName = params.get("StateMachineResourceName")
         self.Input = params.get("Input")
         self.Name = params.get("Name")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class StartExecutionResponse(AbstractModel):
@@ -545,7 +644,7 @@ class StartExecutionResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param ExecutionResourceName: 执行资源名
         :type ExecutionResourceName: str
         :param StartDate: 执行开始时间
@@ -570,7 +669,7 @@ class StateMachine(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param FlowServiceResource: 状态机资源
         :type FlowServiceResource: str
         :param Type: 状态机类型。EXPRESS，STANDARD
@@ -624,4 +723,52 @@ class StateMachine(AbstractModel):
         self.Modifier = params.get("Modifier")
         self.FlowServiceId = params.get("FlowServiceId")
         self.TemplateId = params.get("TemplateId")
-        self.Description = params.get("Description")
\ No newline at end of file
+        self.Description = params.get("Description")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class StopExecutionRequest(AbstractModel):
+    """StopExecution请求参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param ExecutionQrn: 执行名称
+        :type ExecutionQrn: str
+        """
+        self.ExecutionQrn = None
+
+
+    def _deserialize(self, params):
+        self.ExecutionQrn = params.get("ExecutionQrn")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
+
+
+class StopExecutionResponse(AbstractModel):
+    """StopExecution返回参数结构体
+
+    """
+
+    def __init__(self):
+        r"""
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
\ No newline at end of file
